# DITA Custom XSLT

**dita-custom-xslt** is a set of XSLT stylesheets that convert a generic DITA topic to a specialized DITA concept, reference, or task. **dita_convert** is a Python 3 package that provides a convenient access to these stylesheets and a command-line utility to perform the conversions.

In combination with [asciidoctor-dita-topic](https://github.com/jhradilek/asciidoctor-dita-topic), this project can be used to rapidly convert AsciiDoc content to DITA.

## Installation

Install the `dita_convert` Python package:

```
python3 -m pip install --upgrade dita-convert
```

## Usage

### Using the command-line interface

To convert a DITA topic to a specialized DITA content type, run the following command:

```
python3 -m dita.convert -t TYPE TOPIC_FILE
```

For convenience, the package also provides a wrapper script that you can run directly as follows:

```
dita-convert -t TYPE TOPIC_FILE
```

Available `TYPE` values are `concept`, `reference`, `task`, and `task-gen` for converting files generated by [asciidoctor-dita-topic](https://github.com/jhradilek/asciidoctor-dita-topic) that follow the guidelines for procedure modules as defined  in the [Modular Documentation Reference Guide](https://redhat-documentation.github.io/modular-docs/).

### Using the Python interface 

To convert a DITA topic to a specialized DITA content type, the **dita_convert** package exports the corresponding `to_concept()`, `to_reference()`, `to_task()`, and `to_task_generated()` functions that return an ElementTree object:

```python
import sys

from lxml import etree
from dita.convert import to_task

# Parse the contents of a sample DITA topic file:
topic = etree.parse("topic.dita")

# Report possible errors:
try:
    # Convert the DITA topic to a DITA task:
    task  = to_task(topic)
except etree.XSLTApplyError as msg:
    # Print the error message to standard error output:
    print(msg, file=sys.stderr)

    # Terminate the script:
    sys.exit(1)

# Report possible warnings:
for error in to_task.error_log:
    # Print the warning message to standard error output:
    print(error.message, file=sys.stderr)

# Print the resulting XML to standard output:
print(str(task))
```

If you prefer to work with the underlying XSLT stylesheets directly, you can access their Path objects as follows:

```python
from dita.convert import xslt

# Print the full path to the XSLT stylesheet for DITA reference:
print(xslt.reference)
```

Available variables are `concept`, `reference`, `task`, and `task_generated`.

## Copyright

Copyright © 2024, 2025 Jaromir Hradilek

This program is free software, released under the terms of the MIT license. It is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
